summaryrefslogtreecommitdiffstats
path: root/ksvg/plugin
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /ksvg/plugin
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'ksvg/plugin')
-rw-r--r--ksvg/plugin/backends/agg/AggCanvasItems.cpp34
-rw-r--r--ksvg/plugin/backends/agg/AggCanvasItems.h8
-rw-r--r--ksvg/plugin/backends/libart/LibartCanvas.cpp24
-rw-r--r--ksvg/plugin/backends/libart/LibartCanvasItems.cpp48
-rw-r--r--ksvg/plugin/backends/libart/LibartCanvasItems.h6
-rw-r--r--ksvg/plugin/ksvg_plugin.cpp4
6 files changed, 62 insertions, 62 deletions
diff --git a/ksvg/plugin/backends/agg/AggCanvasItems.cpp b/ksvg/plugin/backends/agg/AggCanvasItems.cpp
index 1052edb8..36b84e86 100644
--- a/ksvg/plugin/backends/agg/AggCanvasItems.cpp
+++ b/ksvg/plugin/backends/agg/AggCanvasItems.cpp
@@ -239,13 +239,13 @@ void AggShape::update(CanvasItemUpdate reason, int param1, int param2)
m_fillPainter->update(m_style);
if(m_strokePainter)
m_strokePainter->update(m_style);
- m_canvas->invalidate(this, false);
+ m_canvas->tqinvalidate(this, false);
}
else if(reason == UPDATE_TRANSFORM)
{
freeSVPs();
init();
- m_canvas->invalidate(this, true);
+ m_canvas->tqinvalidate(this, true);
}
else if(reason == UPDATE_ZOOM)
init();
@@ -257,13 +257,13 @@ void AggShape::update(CanvasItemUpdate reason, int param1, int param2)
else if(reason == UPDATE_LINEWIDTH)
{
init();
- m_canvas->invalidate(this, true);
+ m_canvas->tqinvalidate(this, true);
}
}
-void AggShape::draw(SVGShapeImpl *shape)
+void AggShape::draw(SVGShapeImpl *tqshape)
{
- if(!m_referenced && (!m_style->getVisible() || !m_style->getDisplay() || !shape->directRender()))
+ if(!m_referenced && (!m_style->getVisible() || !m_style->getDisplay() || !tqshape->directRender()))
return;
//if(!m_strokeSVP && (!m_fillSVP || !m_style->isFilled()))
@@ -292,14 +292,14 @@ void AggShape::draw(SVGShapeImpl *shape)
m_curved.approximation_scale(pow(m_transform.scale(), 0.75));
if(m_fillPainter)
- m_fillPainter->draw(m_canvas, m_curved_trans, m_style, shape);
+ m_fillPainter->draw(m_canvas, m_curved_trans, m_style, tqshape);
if(m_strokePainter)
- m_strokePainter->draw(m_canvas, m_curved_stroked_trans, m_style, shape);
+ m_strokePainter->draw(m_canvas, m_curved_stroked_trans, m_style, tqshape);
}
-bool AggShape::isVisible(SVGShapeImpl *shape)
+bool AggShape::isVisible(SVGShapeImpl *tqshape)
{
- return m_referenced || (m_style->getVisible() && m_style->getDisplay() && shape->directRender());
+ return m_referenced || (m_style->getVisible() && m_style->getDisplay() && tqshape->directRender());
}
void AggShape::calcSVPs(const SVGMatrixImpl *matrix)
@@ -376,14 +376,14 @@ void AggStrokePaintServer::update(SVGStylableImpl *style)
}
template<class VertexSource>
-void AggStrokePaintServer::draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *shape)
+void AggStrokePaintServer::draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *tqshape)
{
canvas->m_ras.reset();
if(style->getStrokeColor()->paintType() == SVG_PAINTTYPE_URI)
{
- AggPaintServer *pserver = static_cast<AggPaintServer *>(SVGPaintServerImpl::paintServer(shape->ownerDoc(), style->getStrokeColor()->uri().string()));
+ AggPaintServer *pserver = static_cast<AggPaintServer *>(SVGPaintServerImpl::paintServer(tqshape->ownerDoc(), style->getStrokeColor()->uri().string()));
if(!pserver) return;
- pserver->setBBoxTarget(shape);
+ pserver->setBBoxTarget(tqshape);
// TODO : Clipping
if(!pserver->finalized())
@@ -425,14 +425,14 @@ void AggFillPaintServer::update(SVGStylableImpl *style)
}
template<class VertexSource>
-void AggFillPaintServer::draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *shape)
+void AggFillPaintServer::draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *tqshape)
{
canvas->m_ras.reset();
if(style->getFillColor()->paintType() == SVG_PAINTTYPE_URI)
{
- AggPaintServer *pserver = static_cast<AggPaintServer *>(SVGPaintServerImpl::paintServer(shape->ownerDoc(), style->getFillColor()->uri().string()));
+ AggPaintServer *pserver = static_cast<AggPaintServer *>(SVGPaintServerImpl::paintServer(tqshape->ownerDoc(), style->getFillColor()->uri().string()));
if(!pserver) return;
- pserver->setBBoxTarget(shape);
+ pserver->setBBoxTarget(tqshape);
// TODO : Clipping
if(!pserver->finalized())
@@ -1166,13 +1166,13 @@ void AggText::update(CanvasItemUpdate reason, int param1, int param2)
svpelement = ++it;
}
- m_canvas->invalidate(this, false);
+ m_canvas->tqinvalidate(this, false);
}
else if(reason == UPDATE_TRANSFORM)
{
clearCurved();
init();
- m_canvas->invalidate(this, true);
+ m_canvas->tqinvalidate(this, true);
}
else if(reason == UPDATE_ZOOM)
{
diff --git a/ksvg/plugin/backends/agg/AggCanvasItems.h b/ksvg/plugin/backends/agg/AggCanvasItems.h
index f6b1d44a..7612b234 100644
--- a/ksvg/plugin/backends/agg/AggCanvasItems.h
+++ b/ksvg/plugin/backends/agg/AggCanvasItems.h
@@ -270,7 +270,7 @@ namespace KSVG
AggFillPaintServer(SVGStylableImpl *style);
void update(SVGStylableImpl *style);
template<class VertexSource>
- void draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *shape);
+ void draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *tqshape);
private:
agg::rgba8 m_color;
@@ -282,7 +282,7 @@ namespace KSVG
AggStrokePaintServer(SVGStylableImpl *style);
void update(SVGStylableImpl *style);
template<class VertexSource>
- void draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *shape);
+ void draw(AggCanvas *canvas, VertexSource &vs, SVGStylableImpl *style, SVGShapeImpl *tqshape);
private:
agg::rgba8 m_color;
@@ -311,11 +311,11 @@ namespace KSVG
virtual bool fillContains(const TQPoint &p);
virtual bool strokeContains(const TQPoint &p);
virtual void update(CanvasItemUpdate reason, int param1 = 0, int param2 = 0);
- void draw(SVGShapeImpl *shape);
+ void draw(SVGShapeImpl *tqshape);
void calcSVPs(const SVGMatrixImpl *matrix);
virtual void init();
virtual void init(const SVGMatrixImpl *);
- bool isVisible(SVGShapeImpl *shape);
+ bool isVisible(SVGShapeImpl *tqshape);
void setRenderContext(RenderContext context) { m_context = context; }
diff --git a/ksvg/plugin/backends/libart/LibartCanvas.cpp b/ksvg/plugin/backends/libart/LibartCanvas.cpp
index 55b371dd..1d2ee30c 100644
--- a/ksvg/plugin/backends/libart/LibartCanvas.cpp
+++ b/ksvg/plugin/backends/libart/LibartCanvas.cpp
@@ -187,15 +187,15 @@ CanvasPaintServer *LibartCanvas::createPaintServer(SVGElementImpl *pserver)
void LibartCanvas::drawImage(TQImage image, SVGStylableImpl *style, const SVGMatrixImpl *matrix, const KSVGPolygon& clippingPolygon)
{
- SVGShapeImpl *shape = dynamic_cast<SVGShapeImpl *>(style);
+ SVGShapeImpl *tqshape = dynamic_cast<SVGShapeImpl *>(style);
- if(shape)
+ if(tqshape)
{
if(image.depth() != 32)
image = image.convertDepth(32);
ArtSVP *imageBorder = svpFromPolygon(clippingPolygon);
- ArtSVP *clipSvp = clipSingleSVP(imageBorder, shape);
+ ArtSVP *clipSvp = clipSingleSVP(imageBorder, tqshape);
ArtDRect bbox;
art_drect_svp(&bbox, clipSvp);
@@ -214,7 +214,7 @@ void LibartCanvas::drawImage(TQImage image, SVGStylableImpl *style, const SVGMat
TQRect screenBBox(x0, y0, x1 - x0 + 1, y1 - y0 + 1);
- TQByteArray mask = SVGMaskElementImpl::maskRectangle(shape, screenBBox);
+ TQByteArray mask = SVGMaskElementImpl::maskRectangle(tqshape, screenBBox);
double affine[6];
KSVGHelper::matrixToAffine(matrix, affine);
@@ -266,10 +266,10 @@ ArtSVP *LibartCanvas::clippingRect(const TQRect &rect, const SVGMatrixImpl *ctm)
return result;
}
-ArtSVP *LibartCanvas::clipSingleSVP(ArtSVP *svp, SVGShapeImpl *shape)
+ArtSVP *LibartCanvas::clipSingleSVP(ArtSVP *svp, SVGShapeImpl *tqshape)
{
ArtSVP *clippedSvp = copy_svp(svp);
- SVGStylableImpl *style = dynamic_cast<SVGStylableImpl *>(shape);
+ SVGStylableImpl *style = dynamic_cast<SVGStylableImpl *>(tqshape);
if(style)
{
@@ -282,7 +282,7 @@ ArtSVP *LibartCanvas::clipSingleSVP(ArtSVP *svp, SVGShapeImpl *shape)
if(clipPath)
{
LibartClipPath *lclip = dynamic_cast<LibartClipPath *>(clipPath);
- reinterpret_cast<SVGClipPathElementImpl *>(clipPath->element())->setBBoxTarget(shape);
+ reinterpret_cast<SVGClipPathElementImpl *>(clipPath->element())->setBBoxTarget(tqshape);
lclip->init();
@@ -296,7 +296,7 @@ ArtSVP *LibartCanvas::clipSingleSVP(ArtSVP *svp, SVGShapeImpl *shape)
}
}
- SVGSVGElementImpl *svg = dynamic_cast<SVGSVGElementImpl *>(shape);
+ SVGSVGElementImpl *svg = dynamic_cast<SVGSVGElementImpl *>(tqshape);
// Clip outer svg, unless width and height not set
if(svg && (!svg->isRootElement() || !svg->getAttribute("width").isEmpty() || !svg->getAttribute("height").isEmpty()) && !svg->getOverflow())
@@ -308,13 +308,13 @@ ArtSVP *LibartCanvas::clipSingleSVP(ArtSVP *svp, SVGShapeImpl *shape)
clippedSvp = s;
}
- if(dynamic_cast<SVGPatternElementImpl *>(shape) != 0)
+ if(dynamic_cast<SVGPatternElementImpl *>(tqshape) != 0)
{
// TODO: inherit clipping paths into tile space
}
- else if(dynamic_cast<SVGMarkerElementImpl *>(shape) != 0)
+ else if(dynamic_cast<SVGMarkerElementImpl *>(tqshape) != 0)
{
- SVGMarkerElementImpl *marker = static_cast<SVGMarkerElementImpl *>(shape);
+ SVGMarkerElementImpl *marker = static_cast<SVGMarkerElementImpl *>(tqshape);
if(!marker->clipShape().isEmpty())
{
@@ -329,7 +329,7 @@ ArtSVP *LibartCanvas::clipSingleSVP(ArtSVP *svp, SVGShapeImpl *shape)
}
else
{
- SVGElementImpl *element = dynamic_cast<SVGElementImpl *>(shape);
+ SVGElementImpl *element = dynamic_cast<SVGElementImpl *>(tqshape);
DOM::Node parentNode = element->parentNode();
if(!parentNode.isNull())
diff --git a/ksvg/plugin/backends/libart/LibartCanvasItems.h b/ksvg/plugin/backends/libart/LibartCanvasItems.h
index 1e750144..b5b9984b 100644
--- a/ksvg/plugin/backends/libart/LibartCanvasItems.h
+++ b/ksvg/plugin/backends/libart/LibartCanvasItems.h
@@ -138,7 +138,7 @@ namespace KSVG
virtual ~LibartPainter() {}
void update(SVGStylableImpl *style);
- void draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *style, SVGShapeImpl *shape);
+ void draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *style, SVGShapeImpl *tqshape);
virtual float opacity(SVGStylableImpl *style) const = 0;
virtual unsigned short paintType(SVGStylableImpl *style) const = 0;
@@ -195,8 +195,8 @@ namespace KSVG
virtual bool fillContains(const TQPoint &p);
virtual bool strokeContains(const TQPoint &p);
virtual void update(CanvasItemUpdate reason, int param1 = 0, int param2 = 0);
- void draw(SVGShapeImpl *shape);
- bool isVisible(SVGShapeImpl *shape);
+ void draw(SVGShapeImpl *tqshape);
+ bool isVisible(SVGShapeImpl *tqshape);
virtual void init();
virtual void init(const SVGMatrixImpl *);
diff --git a/ksvg/plugin/ksvg_plugin.cpp b/ksvg/plugin/ksvg_plugin.cpp
index 49a95760..1a2e3f8d 100644
--- a/ksvg/plugin/ksvg_plugin.cpp
+++ b/ksvg/plugin/ksvg_plugin.cpp
@@ -398,7 +398,7 @@ void KSVGPlugin::update()
void KSVGPlugin::slotSetDescription(const TQString &desc)
{
ksvgd->description = desc;
- emit setStatusBarText(i18n("Description: %1").arg(desc));
+ emit setStatusBarText(i18n("Description: %1").tqarg(desc));
}
void KSVGPlugin::slotSetTitle(const TQString &title)
@@ -409,7 +409,7 @@ void KSVGPlugin::slotSetTitle(const TQString &title)
void KSVGPlugin::slotGotURL(const TQString &text)
{
if(text.isNull() && !ksvgd->description.isEmpty())
- emit setStatusBarText(i18n("Description: %1").arg(ksvgd->description));
+ emit setStatusBarText(i18n("Description: %1").tqarg(ksvgd->description));
else
emit setStatusBarText(text);
}
diff --git a/ksvg/plugin/backends/libart/LibartCanvasItems.cpp b/ksvg/plugin/backends/libart/LibartCanvasItems.cpp
index aca4c517..1434931b 100644
--- a/ksvg/plugin/backends/libart/LibartCanvasItems.cpp
+++ b/ksvg/plugin/backends/libart/LibartCanvasItems.cpp
@@ -129,9 +129,9 @@ TQRect LibartShape::bbox() const
return rect;
}
-bool LibartShape::isVisible(SVGShapeImpl *shape)
+bool LibartShape::isVisible(SVGShapeImpl *tqshape)
{
- return m_referenced || (m_style->getVisible() && m_style->getDisplay() && shape->directRender());
+ return m_referenced || (m_style->getVisible() && m_style->getDisplay() && tqshape->directRender());
}
bool LibartShape::fillContains(const TQPoint &p)
@@ -160,12 +160,12 @@ void LibartShape::update(CanvasItemUpdate reason, int param1, int param2)
m_fillPainter->update(m_style);
if(m_strokePainter)
m_strokePainter->update(m_style);
- m_canvas->invalidate(this, false);
+ m_canvas->tqinvalidate(this, false);
}
else if(reason == UPDATE_TRANSFORM)
{
reset();
- m_canvas->invalidate(this, true);
+ m_canvas->tqinvalidate(this, true);
}
else if(reason == UPDATE_ZOOM)
reset();
@@ -184,13 +184,13 @@ void LibartShape::update(CanvasItemUpdate reason, int param1, int param2)
m_strokeSVP = 0;
}
init();
- m_canvas->invalidate(this, true);
+ m_canvas->tqinvalidate(this, true);
}
}
-void LibartShape::draw(SVGShapeImpl *shape)
+void LibartShape::draw(SVGShapeImpl *tqshape)
{
- if(!m_referenced && (!m_style->getVisible() || !m_style->getDisplay() || !shape->directRender()))
+ if(!m_referenced && (!m_style->getVisible() || !m_style->getDisplay() || !tqshape->directRender()))
return;
bool fillOk = m_fillSVP && m_style->isFilled();
@@ -199,10 +199,10 @@ void LibartShape::draw(SVGShapeImpl *shape)
if(fillOk || strokeOk)
{
if(m_fillPainter && m_fillSVP)
- m_fillPainter->draw(m_canvas, m_fillSVP, m_style, shape);
+ m_fillPainter->draw(m_canvas, m_fillSVP, m_style, tqshape);
if(m_strokePainter && m_strokeSVP)
- m_strokePainter->draw(m_canvas, m_strokeSVP, m_style, shape);
+ m_strokePainter->draw(m_canvas, m_strokeSVP, m_style, tqshape);
}
}
@@ -230,9 +230,9 @@ void LibartPainter::update(SVGStylableImpl *style)
}
}
-void LibartPainter::draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *style, SVGShapeImpl *shape)
+void LibartPainter::draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *style, SVGShapeImpl *tqshape)
{
- ArtSVP *clippedSvp = canvas->clipSingleSVP(svp, shape);
+ ArtSVP *clippedSvp = canvas->clipSingleSVP(svp, tqshape);
// Clipping
ArtDRect bbox;
@@ -252,15 +252,15 @@ void LibartPainter::draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *st
TQRect screenBBox(x0, y0, x1 - x0 + 1, y1 - y0 + 1);
- TQByteArray mask = SVGMaskElementImpl::maskRectangle(shape, screenBBox);
+ TQByteArray mask = SVGMaskElementImpl::maskRectangle(tqshape, screenBBox);
if(paintType(style) == SVG_PAINTTYPE_URI)
{
- LibartPaintServer *pserver = static_cast<LibartPaintServer *>(SVGPaintServerImpl::paintServer(shape->ownerDoc(), paintUri(style)));
+ LibartPaintServer *pserver = static_cast<LibartPaintServer *>(SVGPaintServerImpl::paintServer(tqshape->ownerDoc(), paintUri(style)));
if(pserver)
{
- pserver->setBBoxTarget(shape);
+ pserver->setBBoxTarget(tqshape);
if(!pserver->finalized())
pserver->finalizePaintServer();
pserver->render(canvas, clippedSvp, opacity(style), mask, screenBBox);
@@ -1285,28 +1285,28 @@ void LibartClipPath::init()
for(; !node.isNull(); node = node.nextSibling())
{
SVGElementImpl *element = m_clipPath->ownerDoc()->getElementFromHandle(node.handle());
- SVGShapeImpl *shape = dynamic_cast<SVGShapeImpl *>(element);
+ SVGShapeImpl *tqshape = dynamic_cast<SVGShapeImpl *>(element);
SVGTestsImpl *tests = dynamic_cast<SVGTestsImpl *>(element);
bool ok = tests ? tests->ok() : true;
- if(element && shape && ok && !shape->isContainer())
+ if(element && tqshape && ok && !tqshape->isContainer())
{
- LibartClipItem *clipElement = dynamic_cast<LibartClipItem *>(shape->item());
+ LibartClipItem *clipElement = dynamic_cast<LibartClipItem *>(tqshape->item());
- if(dynamic_cast<LibartText *>(shape->item()))
+ if(dynamic_cast<LibartText *>(tqshape->item()))
{
// The cast to a clipElement above is failing when it is valid. But only
// in the plugin - svgdisplay works fine. What's going on? (Adrian)
- clipElement = dynamic_cast<LibartText *>(shape->item());
+ clipElement = dynamic_cast<LibartText *>(tqshape->item());
}
if(clipElement)
{
clipElement->setRenderContext(CLIPPING);
- // Push coordinate system down to children.
- SVGLocatableImpl *locatable = dynamic_cast<SVGLocatableImpl *>(shape);
+ // Push coordinate system down to tqchildren.
+ SVGLocatableImpl *locatable = dynamic_cast<SVGLocatableImpl *>(tqshape);
if(locatable)
locatable->updateCachedScreenCTM(clipMatrix);
@@ -1514,13 +1514,13 @@ void LibartText::update(CanvasItemUpdate reason, int param1, int param2)
fill = ++it1;
stroke = ++it2;
}
- m_canvas->invalidate(this, false);
+ m_canvas->tqinvalidate(this, false);
}
else if(reason == UPDATE_TRANSFORM)
{
clearSVPs();
init();
- m_canvas->invalidate(this, true);
+ m_canvas->tqinvalidate(this, true);
}
else if(reason == UPDATE_ZOOM)
{
@@ -2085,7 +2085,7 @@ void LibartRadialGradient::render(KSVGCanvas *c, ArtSVP *svp, float opacity, TQB
// Here we're undoing the unit-converter's work because putting the
// bounding box transform into the matrix here lets the gradient transform
// sit at the right point in the chain to work with bounding box coordinates.
// It also produces the elliptical shape due to the non-uniform scaling.
SVGRectImpl *userBBox = getBBoxTarget()->getBBox();
double width = userBBox->width();
@@ -2085,7 +2085,7 @@ void LibartRadialGradient::render(KSVGCanvas *c, ArtSVP *svp, float opacity, TQB
// bounding box transform into the matrix here lets the gradient transform
// sit at the right point in the chain to work with bounding box coordinates.
- // It also produces the elliptical shape due to the non-uniform scaling.
+ // It also produces the elliptical tqshape due to the non-uniform scaling.
SVGRectImpl *userBBox = getBBoxTarget()->getBBox();
double width = userBBox->width();